@@ -101,13 +101,16 @@ class Domoticz(IPlugin):
 				log.msg("response   :  %s" % (jsonreq))
 				log.msg("*********************************************  : ")
 				log.msg("jsonreq.result :  %s" % (jsonreq['result']))
-				total = len (jsonreq['result'])
-				log.msg(" total    :  %s" % (total))
-				total = range(total)
-				log.msg(" total - range    :  %s" % (total))
-				for xx in jsonreq['result'] :
-					log.msg(" jsonreq - idx   :  %s" % (xx['idx']))
-					log.msg("   jsonreq - type   :  %s" % (xx['Type']))
+				for rt in jsonreq['result'] :
+					log.msg(" jsonreq - idx   :  %s" % (rt['idx']))
+					log.msg("   jsonreq - type   :  %s" % (rt['Type']))
+					if int(rs['idx']) == rt['idx']:
+						log.msg(" jsonreq - idx   :  %s" % (rt['idx']))
+						log.msg(" jsonreq - batlevel   :  %s" % (rt['BatteryLevel']))
+						log.msg(" jsonreq - idx   :  %s" % (rt['Temp']))
+						log.msg(" jsonreq - idx   :  %s" % (rt['Name']))
+						log.msg(" jsonreq - idx   :  %s" % (rt['Data']))
+							
 		if bodies == "":
 			bodies = "j'ai rien compris aux devices"
 		return {"plugin": "Domoticz",
